@@ -899,6 +899,10 @@ def _add_source(source, code, path, lineno=1):
     source.append('#line %d "%s"' % (lineno, path))
     source.append(code)
 
+def read_text(f):
+    with open(f) as fid:
+        return fid.read()
+
 def make_source(model_info):
     # type: (ModelInfo) -> Dict[str, str]
     """
@@ -929,7 +933,7 @@ def make_source(model_info):
     # Load templates and user code
     kernel_header = load_template('kernel_header.c')
     kernel_code = load_template('kernel_iq.c')
-    user_code = [(f, open(f).read()) for f in model_sources(model_info)]
+    user_code = [(f, read_text(f)) for f in model_sources(model_info)]
 
     # Build initial sources
     source = []
@@ -989,8 +993,8 @@ def make_source(model_info):
 
     # Validity check macro.  Putting it here so that line number
     # jiggering is short-lived.
-    source.append('#line %d "%s"'
-                  % (model_info.lineno.get('valid', 1), model_info.basefile))
+    _add_source(source, valid, model_info.basefile,
+                lineno=model_info.lineno.get('valid', 1))
     source.append(valid)
 
     # Define the parameter table
