@@ -11,6 +11,7 @@ from __future__ import print_function
 from copy import copy
 from os.path import abspath, basename, splitext
 import inspect
+import logging
 
 import numpy as np  # type: ignore
 
@@ -32,6 +33,8 @@ else:
     TestCondition = Tuple[ParameterSetUser, TestInput, TestValue]
 # pylint: enable=unused-import
 
+logger = logging.getLogger(__name__)
+
 # If MAX_PD changes, need to change the loop macros in kernel_iq.c
 MAX_PD = 5 #: Maximum number of simultaneously polydisperse parameters
 
@@ -966,6 +969,36 @@ def make_model_info(kernel_module):
     if callable(info.Iq) and parameters.has_2d:
         raise ValueError("oriented python models not supported")
 
+    # CRUFT: support old-style ER() for effective radius
+    # radius_effective(mode, ...), if it is present, should be a callable
+    # python function accepting the shape parameters, and have a corresponding
+    # Iq function in python (Fq in python is not suported at this time).
+    # If ER() is present, it might represent a 4.2 model that hasn't been
+    # converted, or it might represent a 4.2+5.0 model with both ER and
+    # radius_effective defined. Unfortunately we can't easily tell whether
+    # radius_effective is defined in the C sources without loading them,
+    # so just issue a warning if we see ER in a C model.
+    ER = getattr(kernel_module, 'ER', None)
+    if ER is not None:
+        if callable(info.Iq) and info.radius_effective is None:
+            info.radius_effective_modes = ['ER']
+            info.radius_effective = lambda mode, *args: ER(*args)
+            # TODO: uncomment the following for the sasview 4.3 release
+            #logger.warning(
+            #    "ER(...) deprecated. Replace with radius_effective(mode, ...)."
+            #    " See plugin model docs for details."
+            #)
+        else:
+            logger.warning(
+                "ER(...) function ignored. Using radius_effective(mode, ...)"
+                " instead if it exists.")
+    ## --- untested, so left unsupported for now ---
+    ## CRUFT: support old-style VR for form/shell ratio
+    #if info.shell_volume is None:
+    #    VR = getattr(kernel_module, 'VR')
+    #    if VR is not None:
+    #        info.shell_volume = lambda *args: info.form_volume(*args)*VR(*args)
+
     info.lineno = {}
     _find_source_lines(info, kernel_module)
     return info
