@@ -39,8 +39,8 @@ the $q$ vector is defined as
 References
 ----------
 
-.. [#] F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
-.. [#] J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
+#.  F Nallet, R Laversanne, and D Roux, *J. Phys. II France*, 3, (1993) 487-502
+#.  J Berghausen, J Zipfel, P Lindner, W Richtering, *J. Phys. Chem. B*, 105, (2001) 11081-11088
 
 Authorship and Verification
 ----------------------------
@@ -101,10 +101,6 @@ def random():
     )
     return pars
 
-demo = dict(scale=1, background=0,
-            sld=6, sld_solvent=1,
-            thickness=40,
-            thickness_pd=0.2, thickness_pd_n=40)
 #  [(qx1, qy1), (qx2, qy2), ...], [I(qx1,qy1), I(qx2,qy2), ...]],
 tests = [
     [{'scale': 1.0, 'background': 0.0, 'thickness': 50.0,
