@@ -87,7 +87,7 @@ of the $q$ vector which is defined as
 Reference
 ---------
 
-.. [#] M Bergstrom, J S Pedersen, P Schurtenberger, S U Egelhaaf, *J. Phys. Chem. B*, 103 (1999) 9888-9897
+#.  M Bergstrom, J S Pedersen, P Schurtenberger, S U Egelhaaf, *J. Phys. Chem. B*, 103 (1999) 9888-9897
 
 Authorship and Verification
 ----------------------------
@@ -152,11 +152,6 @@ def random():
     )
     return pars
 
-demo = dict(scale=1, background=0,
-            thickness=33, Nlayers=20, d_spacing=250, sigma_d=0.2,
-            sld=1.0, sld_solvent=6.34,
-            thickness_pd=0.2, thickness_pd_n=40)
-
 #
 tests = [
     [{'scale': 1.0, 'background': 0.0, 'thickness': 33., 'Nlayers': 20.0,
