@@ -50,7 +50,7 @@ and the $y$ axis) and the averaging $\left<\ldots\right>$ is applied over all
 orientations.
 
 Assuming $a = A/B < 1$, $b = B /B = 1$, and $c = C/B > 1$, the
-form factor is given by (Mittelbach and Porod, 1961 [#Mittelbach]_)
+form factor is given by (Mittelbach and Porod, 1961 [#Mittelbach1961]_)
 
 .. math::
 
@@ -176,10 +176,12 @@ angles.
 References
 ----------
 
-.. [#Mittelbach] P Mittelbach and G Porod, *Acta Physica Austriaca*,
+See also Nayuk [#Nayuk2012]_ and Onsager [#Onsager1949]_.
+
+.. [#Mittelbach1961] P Mittelbach and G Porod, *Acta Physica Austriaca*,
    14 (1961) 185-211
-.. [#] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
-.. [#] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
+.. [#Nayuk2012] R Nayuk and K Huber, *Z. Phys. Chem.*, 226 (2012) 837-854
+.. [#Onsager1949] L. Onsager, *Ann. New York Acad. Sci.*, 51 (1949) 627-659
 
 Authorship and Verification
 ----------------------------
@@ -247,18 +249,6 @@ def random():
     )
     return pars
 
-
-# parameters for demo
-demo = dict(scale=1, background=0,
-            sld=6.3, sld_solvent=1.0,
-            length_a=35, length_b=75, length_c=400,
-            theta=45, phi=30, psi=15,
-            length_a_pd=0.1, length_a_pd_n=10,
-            length_b_pd=0.1, length_b_pd_n=1,
-            length_c_pd=0.1, length_c_pd_n=1,
-            theta_pd=10, theta_pd_n=1,
-            phi_pd=10, phi_pd_n=1,
-            psi_pd=10, psi_pd_n=10)
 # rkh 7/4/17 add random unit test for 2d, note make all params different,
 # 2d values not tested against other codes or models
 qx, qy = 0.2 * np.cos(np.pi/6.), 0.2 * np.sin(np.pi/6.)
