@@ -77,7 +77,4 @@ def random():
     )
     return pars
 
-demo = dict(scale=100, background=1.0,
-            peak_pos=0.05, peak_hwhm=0.005)
-
 tests = [[{'scale':100.0, 'background':1.0}, 0.001, 2.0305]]
