@@ -60,9 +60,9 @@ where the $q$ vector is defined as
 References
 ----------
 
-.. [#] M Teubner, R Strey, *J. Chem. Phys.*, 87 (1987) 3195
-.. [#] K V Schubert, R Strey, S R Kline and E W Kaler, *J. Chem. Phys.*, 101 (1994) 5343
-.. [#] H Endo, M Mihailescu, M. Monkenbusch, J Allgaier, G Gompper, D Richter, B Jakobs, T Sottmann, R Strey, and I Grillo, *J. Chem. Phys.*, 115 (2001), 580
+#.  M Teubner, R Strey, *J. Chem. Phys.*, 87 (1987) 3195
+#.  K V Schubert, R Strey, S R Kline and E W Kaler, *J. Chem. Phys.*, 101 (1994) 5343
+#.  H Endo, M Mihailescu, M. Monkenbusch, J Allgaier, G Gompper, D Richter, B Jakobs, T Sottmann, R Strey, and I Grillo, *J. Chem. Phys.*, 115 (2001), 580
 
 Authorship and Verification
 ----------------------------
@@ -119,7 +119,4 @@ def random():
     )
     return pars
 
-demo = dict(scale=1, background=0, volfraction_a=0.5,
-            sld_a=0.3, sld_b=6.3,
-            d=100.0, xi=30.0)
 tests = [[{}, 0.06, 41.5918888453]]
